@@ -162,18 +162,19 @@ def send_through_pager(s):
     Open up this user's pager and send string s through it.
 
     If I don't find a $PAGER variable and "which less" fails, I'll just
-    print the string.
+    print the damn string.
     """
 
     pager = os.environ.get('PAGER')
 
-    if not pager:
-        return_code = subprocess.call(['which', 'less'])
+    # Look for the less pager.
+    if not pager and subprocess.Popen(
+        ['which', 'less'],
+        stdout=subprocess.PIPE).wait() == 0:
 
-        # The which program returns zero when it found stuff.
-        if return_code == 0:
             pager = 'less'
 
+
     if pager:
         p = subprocess.Popen([pager], stdin=subprocess.PIPE)
         p.communicate(s)
@@ -227,15 +228,33 @@ def edit_with_editor(s=None):
     """
     Open os.environ['EDITOR'] and load in text s.
     
-    Returns the text typed in the editor.
+    Returns the text typed in the editor, after running strip().
     """
 
     # This is the first time I've used with!
     with tempfile.NamedTemporaryFile() as t:
 
         if s:
-            t.write(s)
+            t.write(str(s))
             t.seek(0)
 
         subprocess.call([os.environ.get('EDITOR', 'vi'), t.name])
-        return t.read()
+        return t.read().strip()
+
+
+def csum(seq):
+    """
+    Yields the cumulative sum of each element in seq.
+
+    >>> csum([4,3,2,1]) # doctest: +ELLIPSIS 
+    <generator object csum at ...>
+
+    >>> zip([3,2,1], csum([3,2,1]))
+    [(3, 3), (2, 5), (1, 6)]
+    """
+
+    tot = 0
+
+    for x in seq:
+        tot += x
+        yield tot
